#!/usr/bin/perl -w
#ircGraph 0.6.7 - lusers to rrdtool 
#Copyright (C) 2001 Ricardo Sartori
#
#This program is free software; you can redistribute it and/or
#modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation; either version 2
#of the License, or (at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-
#
#Sugestoes e criticas (sem flames!!) mailto:sartori@lrv.ufsc.br
#Suggestions and critics (no flames!) mailto:sartori@lrv.ufsc.br

# Usa Socket e Getopt (sem POSIX long opts)

use integer; # I dont need doubles in this script
require 5.005;
use Socket;
use Getopt::Std;
use strict;
use vars qw($nick $rrdtool $connectto $ircport $ircservers $logfile $rrddir $delay $password $opernick $operpass $onconnectfile $responsedir $response $opt_d $opt_l $opt_c $opt_i $opt_h $configfile $var @servers $pidfile $noinvisible);

	
# Getting the flags
getopt('ci');
getopts('dlh');
# Setting the signals
$SIG{'INT'} = 'intkill';
$SIG{'TERM'} = 'termkill';

if (defined($opt_h)) {
  print("ircGraph 0.6.7 - LUSERS to RRD\nCopyright (C) 2001 Ricardo Sartori\nhttp://wmaker.lrv.ufsc.br/?pagina=ircgraph\n\nUsage: ./ircgraph.pl -c configfile [options], where options are:\n -i IP ADDRESS, ircgraph will bind to this IP\n -d debug mode on\n -l will log data to a logfile\n -h this help\n");
  exit(0);
}

# Getting the value of $configfile
if (defined($opt_c)) {
 $configfile=$opt_c;
} else {
 print("Warn: searching /usr/local/etc/ for an ircgraph.conf file\n");
 if (-r "/usr/local/etc/ircgraph.conf") { 
  $configfile="/usr/local/etc/ircgraph.conf";
 } else {
  print("Warn: not found, not readable\nWarn: searching for a ./ircgraph.conf file\n");
  if (-r "./ircgraph.conf") {
   $configfile="./ircgraph.conf";
  } else {
   print("Fatal: could not find an ircgraph.conf file. Use the -c option to point one\n");
   exit(0);
  }
 }
}

# Checking if the config file exists/is readable/the type
if (!(-r $configfile) || !(-f $configfile)) {
 print("Fatal: Could not read/find $configfile: ($!)\n");
 exit(0);
} else {
 &debug("main(): Config file $configfile ok\n");
}

# Checking the -i argument
if ($opt_i) {
 if ($opt_i =~ /\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/) {
  &debug("main(): Valid ip: $opt_i\n");
 } else {
  &debug("main(): Invalid ip: $opt_i\n");
  print("Fatal: Invalid ip ($opt_i)\n");
  exit(0);
 }
}


#Reading config file ang getting variables
if (($nick, $rrdtool, $connectto, $ircport, $ircservers, $logfile, $rrddir, $delay, $pidfile, $noinvisible, $password, $opernick, $operpass, $onconnectfile, $responsedir) = (&readconf($configfile))[0,1,2,3,4,6,7,8,9,10,11,12,13,14,15]) {
 &log("OK: Config file read...\n");
 &debug("main() Configured settings:\n** RRDTOOL=$rrdtool\n** RRDDIR=$rrddir\n** LOGFILE=$logfile\n** NICK=$nick\n** IRCSERVER/PORT(PASS)=$connectto/$ircport($password)\n** PIDFILE=$pidfile OPERNICK=$opernick\n** ONCONNECT=$onconnectfile\n** RESPONSESDIR=$responsedir\n");
 if ($ircservers) {  		# is $ircservers is set
  $ircservers =~ s/ +//g; 	# erase the " ". OBS: use the g flag (otherwise will go out in the 1st match)
  my(@servidores)=split(",",$ircservers);  # put the servers in the @servidores
  @servers=();		# initializing array @servers
  for (my($i)=0; $i < scalar(@servidores); $i++) {  # foreach server listed in the config file
	  my(@temp_array)=($servidores[$i],0,0,0,0,0,0,0,0); # creates a temporary array with the server name and NULLs
   $servers[$i]=[ @temp_array ];		    # put the temporary array in the @servers[#]
  }
 } else { # if $ircservers is not set
  print("Fatal: you must define at least one ircserver in config file\n");
  exit(0);
 }
} else { # if readconf() did not return ok
 print("Fatal: Could not read configuration file ircgraph.conf\n");
 exit(0);
}

# time to create my pidfile
if ((-e $pidfile) && (-r $pidfile)) {
	print("Fatal: It seems that there is already an ircgraph client running. If this is not correct, erase the $pidfile file and start it again\n");
	exit(0);
} else {
	open(PIDFILE, ">$pidfile") || (print("Fatal: Could not write pidfile $pidfile ($!)\n") && exit(0));
	print(PIDFILE "$$\n");
	close(PIDFILE);
}
		
# Checking if rrdtool is executable
if (-x "$rrdtool") {
 &log("OK: $rrdtool is executable\n");
 &debug("main() OK: $rrdtool is executable\n");
} else {
 &endprog("Fatal: $rrdtool not found\/executable",2);
}

# Checking if I can go/write in $rrddir
if ((-w "$rrddir") && (-x "$rrddir")) {
 &log("OK: $rrddir is writeable/executable\n");
 &debug("main() OK: $rrddir is writeable/executable\n");
} else {
 &endprog("Fatal: $rrddir is not writeable/executable",3);
}

# Checking if I can enter $responsedir
if ($responsedir eq "") {
	&endprog("Fatal: you must define the responses directive in your config file",13);
} else {
	if (-r $responsedir) {
	 	&debug("main() OK: $responsedir directory readable\n");
	} else {
		&debug("main() ERROR: $responsedir not readable\n");
	}
}

 
$response=&readResponses($responsedir);
#printf("Response 251: %s\n", $response->{"251"});

sub readResponses { 
	my($respdir)=@_;
	my(%responseshash,$raw);
	opendir(RESPDIR, "$respdir") || &endprog("Fatal: could not open the Response dir $respdir ($!)",11);
	foreach $raw (readdir(RESPDIR)) {
		open(FILE, "$respdir/$raw") || &endprog("Fatal: could not open the Response $raw ($!)",12);
		#&debug("readResponses(): opened file $respdir/$raw\n");
		if (read(FILE,$responseshash{"$raw"},500)) {
			my($len)=length($responseshash{"$raw"});
			&debug("readResponses(): read $len  bytes from file $respdir/$raw}\n");
		}
	}
	close(FILE);
	close(RESPDIR);
	#opendir(RESPDIR, "$respdir") || &endprog("Error: could not open the Response dir $respdir ($!)",11);
	#        foreach $raw (readdir(RESPDIR)) {
	#        printf("RESPONSE ****** %s \n", $responseshash{'$raw'});
	#}
	return(\%responseshash);
}


# Checks and creates the RRD dbs
for (my($i)=0; $i <= $#servers; $i++) { # foreach server in the array, do
	if ((-e "$rrddir/$servers[$i][0].rrd") && (-r "$rrddir/$servers[$i][0].rrd") && (-w "$rrddir/$servers[$i][0].rrd")) { # if the rrd file exists and can be written/read 
  &log("OK: RRD Database for server $servers[$i][0] found\n");
 } else { # if it does not exists or can't be written/read
  &log("Warn: RRD Database $servers[$i][0] not readable/writeable, creating one\n");
  system("$rrdtool create $rrddir/$servers[$i][0].rrd DS:usuarioslocais:GAUGE:600:U:U DS:ircops:GAUGE:600:U:U DS:usuariosglobais:GAUGE:600:U:U DS:canais:GAUGE:600:U:U DS:invisiveis:GAUGE:600:U:U DS:normais:GAUGE:600:U:U DS:totalservers:GAUGE:600:U:U RRA:AVERAGE:0.5:1:600 RRA:AVERAGE:0.5:6:700 RRA:AVERAGE:0.5:24:775 RRA:AVERAGE:0.5:288:797 RRA:MAX:0.5:1:600 RRA:MAX:0.5:6:700 RRA:MAX:0.5:24:775 RRA:MAX:0.5:288:797")==0 || &endprog("Fatal: could not create $rrddir/$servers[$i][0].rrd ($!)",4);
  if ((-e "$rrddir/$servers[$i][0].rrd") && (-r "$rrddir/$servers[$i][0].rrd") && (-w "$rrddir/$servers[$i][0].rrd"))  { print("OK: database $servers[$i][0].rrd created\n"); } 
 } 
}

if (($onconnectfile ne "") && open(AUTOCON, "$onconnectfile")) {
	$onconnectfile="";
	while (<AUTOCON>) {
		if ($_ !~ /^#.*/) { $onconnectfile=$onconnectfile.$_; }
	}
	close(AUTOCON);
} else {
	&debug("Warn: Could not open/read onconnectfile ($onconnectfile)\n");
	&log("Warn: Could not open/read onconnectfile ($onconnectfile)\n");
	$onconnectfile="";
}
&debug("** AUTOCONNECT SCRIPT:\n$onconnectfile\n");

# Initializing stuff
&log("ircGraph 0.6.7 init (PID: $$) on $^O\n");
&debug("ircGraph 0.6.7 init (PID: $$) on $^O\n");
$0="ircgraph -c $configfile";
if ($opt_l) { $0=$0." -l" }
if ($opt_d) { $0=$0." -d" }
if ($opt_i) { $0=$0." -i $opt_i" }
if (!defined($delay) || ($delay eq "")) { $delay=15 }
&log("OK: init done\n");
&debug("OK: init done\n");

# This is the main loop
while (1) {
   my($conectou,$serveraddr,$rawserver,$last)=(-1);
   ($rawserver) = (gethostbyname($connectto))[4];
   $serveraddr = pack("Sna4x8", 2, $ircport, $rawserver);
   &log("Starting connection to: $connectto $ircport\n");
   &debug("Starting connection to: $connectto $ircport\n");
   socket(SOCKET, AF_INET, SOCK_STREAM, getprotobyname("tcp")) || &endprog("Fatal: Could not create socket ($!)", 5);
   if ($opt_i) { 
       my($rawlocal)=inet_aton($opt_i);
       &debug("Bindindg socket to ip: $opt_i...\n");
       if (bind(SOCKET,sockaddr_in(0,$rawlocal))) { 
		&debug("OK: Socket binded\n");
       } else {
  		&endprog("Fatal: Could not bind socket ($!)", 6);
       }
   }

   if (connect(SOCKET, $serveraddr)){
      select(SOCKET); $| = 1; # autoflush SOCKET
      select(STDOUT); $| = 1; # autoflush STDOUT
      &log("OK: Connected, sending registration info\n");
      &debug("main(): Connected, sending registration info\n");
      if (defined($password) && ($password ne "")) {
	      &debug("main(): Sending password to ircd\n");
	      print(SOCKET "PASS $password\n");
      }
      print(SOCKET "USER ircgraph ircgraph ircgraph065 :http://wmaker.lrv.ufsc.br\n");
      print(SOCKET "NICK $nick\n");
      &log("OK: Register info sent, getting data\n");
      while (<SOCKET>){
         &debug($_);
	 $last=$_; chomp($last);
         my(@i) = split(" ",$_);
         if ($i[1] eq "251") { # servers, global invisible users and global normal users
		$i[0]=~s/://;
		#:irc.something.com.br 251 ircgraph067 :There are 17089 users and 58704 invisible on 38 servers
		#$_=~/^:.+ 251 .+ :.+ (\d+) .+ (\d+) .+ (\d+).*$/;
		my($nservers)=0; my($ninvisible)=0; my($nusers)=0;
		eval($response->{"251"});
		if ($noinvisible) {
			&debug("main(): Hmmm... a 251 reply RFC2812\n");
			&storeinfo(7, $nservers, $i[0]); # storeinfo(7 -> serv
			&storeinfo(5, $nusers, $i[0]); # storeinfo(5 -> visible users
			&storeinfo(4, 0, $i[0]); # storeinfo (4 -> invisible users
			&storeinfo(1, $nusers, $i[0]); #storeinfo(1 -> global users
			&debug("main() Found users: $nusers servers: $nservers invisible: 0\n");
		} else {
			&debug("main(): A 251 reply non-RFC2812\n");
			&storeinfo(7, $nservers, $i[0]); # storeinfo(7 -> servers
			&storeinfo(5, $nusers, $i[0]); # storeinfo(5 -> visible users
			&storeinfo(4, $ninvisible, $i[0]); # storeinfo (4 -> invisible users
			&storeinfo(1, ($nusers+$ninvisible), $i[0]); #storeinfo(1 -> global users
			&debug("main() Found users: $nusers+$ninvisible servers: $nservers invisible: $ninvisible\n");
		}
	}
         elsif ($i[1] eq "252") { # storeinfo(6 -> ircops
		$i[0]=~s/://;
		#:irc.something.com 252 ircgraph065 31 :operators(s) online
		#$_=~/^:.+ 252 .+ (\d+) :.+$/;
		my($nircops)=0;
		eval($response->{"252"});
		&storeinfo(6, $nircops, $i[0]);
		&debug("main(): Found the number of ircops: $nircops\n");
	}
	# Message 265 is not described in RFC2812
	elsif ($i[1] eq "265") { # storeinfo(2 -> local users
		$i[0]=~s/://;
		my($nlocal)=0;
		eval($response->{"265"});
		#:irc.something.com.br 265 ircgraph065 :Current local users: 2799  Max: 3191
		#$_=~/^:.+ 265 .+ :.+ (\d+) .+ (\d+).*$/;
		#my($nlocal)=$1;
		&storeinfo(2, $nlocal, $i[0]);
		&debug("main(): Found the number of local users via response 265: $nlocal\n");
	}
	elsif ($i[1] eq "254") { # storeinfo(3 -> global channels
		$i[0]=~s/://;
		#:irc.something.com.br 254 ircgraph065 1697 :channels formed
		#$_=~/^:.+ 254 .+ (\d+) :.+$/;
		my($nchannels)=0;
		eval($response->{"254"});
		&storeinfo(3, $nchannels, $i[0]);
		&debug("main(): Found the number of channels: $nchannels\n");
	}
	# This is to support Undernet ircd (ircu)
	# Thanks to Federico Sevilla III (Jijo) for this patch
	elsif ($i[1] eq "255") { # storeinfo(2 -> local users
		$i[0]=~s/://;
		#:irc.something.com.br 255 ircgraph065 :I have 5 clients and 2 servers
		#$_=~ /^:.+ 255 .+ :.+ (\d+) .+ (\d+).*$/;
		my($nlocal)=0;
		eval($response->{"255"});
		&storeinfo(2, $nlocal, $i[0]);
		&debug("main(): Found the number of local users via response 255: $nlocal\n");
	}
	elsif (($i[1] eq "266") && ($conectou >= 0)) { # global users
		$i[0]=~s/://;
		#:irc.something.com.br 266 ircgraph065 :Current global users: 75793  Max: 80801
		#$_=~/^:.+ 266 .+ :.+ (\d+) .+ (\d+).*$/;
		my($nglobal)=0;
		eval($response->{"266"});
		&storeinfo(1, $nglobal, $i[0]); # storeinfo(1 -> global users
		&debug("main(): Found the number of global users via response 266: $nglobal\n");
	}
	elsif (($i[1] eq "266") && ($conectou == -1)) {
		&log("OK: Initial data read, preparing to receive MOTD\n");
	}
	elsif ($i[0] eq "PING") {
		print SOCKET "PONG $i[1]\n";
		&debug("<- PING $i[1]\n-> PONG $i[1]\n");
		if ($conectou >= 0) {
			$conectou++;
			for (my($i) = $#servers; $i >= 0; $i--) {
				&rrdupdate($servers[$i][0]);
				print SOCKET "LUSERS * $servers[$i][0]\n";
				&debug("Sent /LUSERS * $servers[$i][0], sleeping $delay seconds\n");
				sleep($delay);
			}
		}
	}
	if ($i[1] eq "NICK") { # changing nick, let's store it
	    $i[2]=~s/://;
            &log("main(): My nick changed to $i[2]\n");
	    $nick=$i[2];
	 }
	 elsif ($i[1] eq "491") {
	    &log("Error(): I could not get oper with $opernick - no host for me\n");
	 }
	 elsif ($i[1] eq "464") {
            &log("Error(): I could not get oper with $opernick - wrong password\n");
	 }
	 elsif ($i[1] eq "381") {
	    &log("main(): Ok, now I am an IRCOperator\n");
	 }
         elsif ($i[1] eq "432") { # Thanks to Henrik Holmboe <elements@eyeque.org>
            close(SOCKET);
            &endprog("Erroneous nickname: $nick", 7);
	 }    
         elsif ($i[1] eq "433") { # Nick with 6 characters
	    my $randomic=sprintf("%4d", rand(1)*10000);
	    &debug("main(): I must change my nickname now\n");
            print SOCKET "NICK if".$randomic."\n";
         }
         elsif ($i[1] eq "437") { # Nick with 6 characters
	    my $randomic=sprintf("%4d", rand(1)*10000);
	    &debug("main(): I must change my nickname now\n");
            print SOCKET "NICK if".$randomic."\n";
         }
         elsif ($i[1] eq "402") { # storeinfo(0 -> server was not found
            $i[0]=~s/://;
            &storeinfo(0,0,$i[3]);
            &log("Server not found: $i[3]\n");
            &debug("Server not found: $i[3]\n");
         }
         elsif (($i[1] eq  "376") || ($i[1] eq "422")) { # End of MOTD || no MOTD
	    if ($i[1] eq "376") {
		    &debug("OK: End of MOTD detected, requesting LUSERS information\n"); 
                    &log("OK: End of MOTD detected, requesting LUSERS information\n");
	    } elsif ($i[1] eq "422") { # Thanks to Jrmie G. <jereme@ircoolchat.net>
		    &debug("OK: Hm... server has no MOTD, requesting LUSERS information\n");
		    &log("OK: Hm.. server has no MOTD, requesting LUSERS information\n");
	    }
	    $onconnectfile="{\nprint SOCKET "."\"$onconnectfile\"\n}";
	    &log("main(): Now I send my onconnect script: $onconnectfile\n");
	    eval($onconnectfile);
	    sleep(5); # Just a little delay
	    if (($opernick ne "") && ($operpass ne "")) {
		    &debug("OK: I was told to get oper with nick: $opernick\n");
		    print SOCKET "OPER $opernick $operpass\n";
	    }
 	    $conectou=0;
            for (my($i) = $#servers; $i >= 0; $i--) {
             print SOCKET "LUSERS * $servers[$i][0]\n";
	     &debug("Sent /LUSERS * $servers[$i][0], sleeping $delay seconds\n");
	     sleep($delay);
            }
         }
      }
      &debug("main() Socket was closed. Last message was:\n--> $last\n");
      &log("Socket was closed. Last message was:\n--> $last\n");
   }
   close(SOCKET);
   &log("Warn: Connection failed ($!)\nWaiting 1 minute to try connection again\n");
   &debug("main() Warn: Connection failed ($!)\nWaiting 1 minute to try connection again\n");
   sleep(60);
}

sub rrdupdate {
 my($servidor)=@_;
 for (my($i)=0; $i <= $#servers; $i++) {
  if ($servers[$i][0] eq $servidor) {
   $servers[$i][8]++;
   system("$rrdtool update $rrddir/$servidor.rrd N:$servers[$i][2]:$servers[$i][6]:$servers[$i][1]:$servers[$i][3]:$servers[$i][4]:$servers[$i][5]:$servers[$i][7]")==0 || &endprog("ERROR: Could not run rrdtool ($!)",8);
   # local, ircops, totalusers, channels, invisible, visible, servers 
   &debug("rrdupdate(): update $servidor N:$servers[$i][2]:$servers[$i][6]:$servers[$i][1]:$servers[$i][3]:$servers[$i][4]:$servers[$i][5]:$servers[$i][7]\n");
   &log("update $servidor N:$servers[$i][2]:$servers[$i][6]:$servers[$i][1]:$servers[$i][3]:$servers[$i][4]:$servers[$i][5]:$servers[$i][7]\n");
  }
 }
}


sub storeinfo {
 # storeinfo(1 -> total users
 # storeinfo(2 -> local users
 # storeinfo(3 -> global channels
 # storeinfo(4 -> invisible users
 # storeinfo(5 -> visible users
 # storeinfo(6 -> ircops
 # storeinfo(7 -> servers
 my($tipo, $dado, $servidor)=@_;
 for (my($i)=0; $i <= $#servers; $i++) {
  if ($servers[$i][0] eq $servidor) {
   if ($tipo == 0) {
    for (my($j) = 1; $j <= 8; $j++) {
     $servers[$i][$j]=0;   
    }
   } else {
    $servers[$i][$tipo]=$dado;
    return(1);
   }
  }
 }
 return(0);
}

sub log {
 if ($opt_l) {
  my($sec,$min,$hour,$day,$mon)=&horalocal();
  my($mensagem) = @_;
  open(LOG,">>$logfile");
  print (LOG "$mon $day $hour:$min:$sec $mensagem");
  close(LOG);
  return(1);
 } else {
  return(0);
 }
} 

sub horalocal {
 (my(@horario)=(localtime(time()))[0,1,2,3,4]);
 my($var);
 for ($var=0; $var<5; $var++) {
  if (length($horario[$var]) <= 1) {
   $horario[$var] = "0".$horario[$var];
  }
 }
 if ($horario[4]==0) { $horario[4]="Jan"; }
 elsif ($horario[4]==1) { $horario[4]="Feb"; }
 elsif ($horario[4]==2) { $horario[4]="Mar"; }
 elsif ($horario[4]==3) { $horario[4]="Apr"; }
 elsif ($horario[4]==4) { $horario[4]="May"; }
 elsif ($horario[4]==5) { $horario[4]="Jun"; }
 elsif ($horario[4]==6) { $horario[4]="Jul"; }
 elsif ($horario[4]==7) { $horario[4]="Ago"; }
 elsif ($horario[4]==8) { $horario[4]="Set"; }
 elsif ($horario[4]==9) { $horario[4]="Out"; }
 elsif ($horario[4]==10) { $horario[4]="Nov"; }
 elsif ($horario[4]==11) { $horario[4]="Dec"; }
 return(@horario);
}


sub debug {
 if ($opt_d) {
  my($mensagem) = @_;
  print(STDOUT $mensagem);
  return(1);
 } else {
  return(0);
 }
}

sub intkill {
 &log("SIGINT, closing program\n");
 print("SIGINT, closing program\n");
 unlink($pidfile);
 close(SOCKET);
 exit(0);
}

sub termkill {
 &log("SIGTERM, closing program\n");
 print("SIGTERM, closing program\n");
 unlink($pidfile);
 close(SOCKET);
 exit(0);
}

sub endprog {
 # Error Codes
 # 2 - could not find rrdtool
 # 3 - rrddir is not writeable/execd
 # 4 - could not create a rrd db
 # 5 - could not create socket
 # 6 - could not bind() the ip
 # 7 - erroneous nickname in config
 # 8 - could not exec rrdtool during rrdupdate()
 # 9 - could not read config file
 # 10 - invalid line on config file
 # 11 - could not open the responses dir
 # 12 - could not open the response file
 my($errorcode, $int)=@_;
 &log("endprog(): $errorcode\n");
 print("$errorcode\n");
 unlink($pidfile);
 exit($int);
}
 

sub readconf {
 my($config)=@_;
 my(@dados)=("","","","","","","","","","",0,"","","","","");
 &debug("readconf(): Reading config file\n");
 open(CONFIG,"$config") || (print("Fatal: could not read $config ($!);\n") && exit(9));
 while (<CONFIG>) {
   if (($_ !~ /^#.*$/) && ($_ !~ /^ *$/)) { # if is not empty and does not start with #
   chomp($_);			# removes /n
   my(@splited)=split(" *= *",$_);
    if ($splited[0] =~ /( *nick *| *rrdtool *| *connectto *| *ircport *| *rrddir *| *ircserver *| *delay *| *logfile *| *pidfile *| *password *| *noinvisible *| *opernick *| *operpass *| *onconnectfile *| *responses *)/) {
     if (!$splited[1]) {
      print("Fatal: Invalid entry - line $. :\"$_\"\n");
      close(CONFIG);
      exit(10);
     } else {
      	if ($splited[0] =~ /\Anick\Z/i) { $dados[0]=$splited[1]; }
	elsif ($splited[0] =~ /\Arrdtool\Z/i) { $dados[1]=$splited[1]; }
	elsif ($splited[0] =~ /\Aconnectto\Z/i) { $dados[2]=$splited[1]; }
	elsif ($splited[0] =~ /\Aircport\Z/i) { $dados[3]=$splited[1]; }
	elsif ($splited[0] =~ /\Aircservers\Z/i) { $dados[4]=$splited[1]; }
	elsif ($splited[0] =~ /\Alogfile\Z/i) { $dados[6]=$splited[1]; }
	elsif ($splited[0] =~ /\Arrddir\Z/i) { $dados[7]=$splited[1]; }
        elsif ($splited[0] =~ /\Adelay\Z/i) { $dados[8]=$splited[1]; }
        elsif ($splited[0] =~ /\Apidfile\Z/i) { $dados[9]=$splited[1]; }
        elsif ($splited[0] =~ /\Anoinvisible\Z/i) { 
      		if ($splited[1] =~ /true/i) { $dados[10]=1; }
		else { $dados[10]=0; }
        }		
	elsif ($splited[0] =~ /\Apassword\Z/i) { $dados[11]=$splited[1]; }
	elsif ($splited[0] =~ /\Aopernick\Z/i) { $dados[12]=$splited[1]; }
	elsif ($splited[0] =~ /\Aoperpass\Z/i) { $dados[13]=$splited[1]; }
	elsif ($splited[0] =~ /\Aonconnectfile\Z/i) { $dados[14]=$splited[1]; }
	elsif ($splited[0] =~ /\Aresponses\Z/i) { $dados[15]=$splited[1]; }
     }
    }
   }
 }
 return(@dados);
}

