#!/usr/bin/perl -w
#ircGraph 0.6.7 - lusers to rrdtool 
#Copyright (C) 2001 Ricardo Sartori
#
#This program is free software; you can redistribute it and/or
#modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation; either version 2
#of the License, or (at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-
#
#Sugestoes e criticas (sem flames!!) mailto:sartori@lrv.ufsc.br

use Getopt::Std;
require 5.005;
use strict;
use vars qw(@servers $graphdir $rrdtool $opt_c $configfile $opt_g $opt_h $opt_d
            $ircservers $connectto $ircport $rrddir $ircserver $template $randomic $colors $options);

getopt('c');
getopts('ghd');

if (defined($opt_h)) {
  print("ircGraph 0.6.7 - LUSERS to RRD\nCopyright (C) 2001 Ricardo Sartori\nhttp://wmaker.lrv.ufsc.br/?pagina=ircgraph\n\nUsage: ./makegraph.pl -c configfile [options], where options are:\n -g Graphics only, makegraph will not create HTML files\n -h this help\n -d show some debug information on stdout\n");
  exit(0);
}

# Setting the $configfile variable
if (defined($opt_c)) {
 $configfile=$opt_c;
} else {
 print("Warn: searching /usr/local/etc/ for an ircgraph.conf file\n");
 if (-r "/usr/local/etc/ircgraph.conf") { 
  $configfile="/usr/local/etc/ircgraph.conf";
 } else {
  print("Warn: not found, not readable\nWarning: searching for a ./ircgraph.conf file\n");
  if (-r "./ircgraph.conf") {
   $configfile="./ircgraph.conf";
  } else {
   print("Fatal: could not find an ircgraph.conf file. Use the -c option to point one\n");
   exit(0);
  }
 }
}

# Checking if the config file is readable/exists/type
if (!(-r $configfile) || !(-f $configfile)) {
 print("Fatal: Could not read/find $configfile: ($!)\n");
 exit(0);
} else {
 &debug("main(): Config file $configfile ok\n");
}
            

# Read config file or die
if (($rrdtool, $connectto, $ircport, $ircservers, $graphdir, $rrddir, $template, $colors, $options) = (&readconf($configfile))[1,2,3,4,5,7,8,9,10]) {
 if ($ircservers) { 
  $ircservers =~ s/ +//g; # leave g flag (otherwise it will get on 1st match)
  my(@servidores)=split(",",$ircservers);
  @servers=();
  for (my($i)=0; $i < scalar(@servidores); $i++) { # for each server in config file
   my(@temp_array)=($servidores[$i],0,0,0,0,0,0,0);
   $servers[$i]=[ @temp_array ];
  }
 }
 print("---------\n");
} else {
 print("Fatal: Could not read configuration file ircgraph.conf");
 exit(0);
}

(-e $graphdir) || die("Fatal: $graphdir does not exist\n");
(-w $graphdir) || die("Fatal: $graphdir is not writeable\n");
((-x $rrdtool) && &debug("main(): RRDtool found and is executable\n")) || die("Fatal: $rrdtool could not be executed\n");

# gets date/time
my($second, $minute, $hour, $daymonth, $month, $year)=&horalocal();
$colors=&parseColors($colors);
$options=&parseOptions($options);

&debug("main(): colors: $colors\n");

if (!($opt_g)) { 
	&debug("main(): -g flag detected, getting seed");
	srand(time());   # a seed
	$randomic=rand(100000); # the random number created
	&debug("main(): Calling create*Html functions");
	&createIndexHtml;
	&createServersHtml;
	&createNetworkHtml;
	&createIRCsHtml;
}

sub createIndexHtml {
  &debug("createIndexHtml(): Creating $graphdir/index-$randomic.temp");
  my($sec,$min,$hour,$day,$mon,$year)=&horalocal();
  open(INDEX, ">$graphdir/index-$randomic.temp") || die("Fatal: Could not create index.html in $graphdir ($!)\n");
  # Creating the header for index.html
  &debug("createIndexHtml(): Permited variables in main-header.html: <\$time_[hour,min,sec,day,mon,year]\$>,<\$connectto\$>,<\$ircport\$>");
  open(TEMPLATE, "$template/main-header.html") || die ("Fatal: Could not open template file $template/main-header.html ($!)\n");
  while(<TEMPLATE>) {
        $_ =~ s/<\$time_hour\$>/$hour/g;
        $_ =~ s/<\$time_min\$>/$min/g;
        $_ =~ s/<\$time_sec\$>/$sec/g;
        $_ =~ s/<\$time_day\$>/$day/g;
        $_ =~ s/<\$time_mon\$>/$mon/g;
        $_ =~ s/<\$time_year\$>/$year/g;
	$_ =~ s/<\$connectto\$>/$connectto/g;
	$_ =~ s/<\$ircport\$>/$ircport/g;
        print(INDEX "$_");
  }
  close(TEMPLATE);
  # Creating the main body
  &debug("createIndexHtml(): Permited variables in main-data.html: <\$time_[hour,min,sec,day,mon,year]\$>,<\$connectto\$>,<\$ircport\$>,<\$ircname\$>");
  open(TEMPLATE, "$template/main-data.html") || die ("Fatal: Could not open template file $template/main-data.html ($!)\n");
  for (my($i)=0; $i <= $#servers; $i++) {
    while(<TEMPLATE>) {	  
       $_ =~ s/<\$time_hour\$>/$hour/g;
       $_ =~ s/<\$time_min\$>/$min/g;
       $_ =~ s/<\$time_sec\$>/$sec/g;
       $_ =~ s/<\$time_day\$>/$day/g;
       $_ =~ s/<\$time_mon\$>/$mon/g;
       $_ =~ s/<\$time_year\$>/$year/g;
       $_ =~ s/<\$connectto\$>/$connectto/g;
       $_ =~ s/<\$ircport\$>/$ircport/g;
       $_ =~ s/<\$ircname\$>/$servers[$i][0]/g;
       print(INDEX "$_");
    }
    &debug("createTemplateIndex(): Loop in the main body -> seeking TEMPLATE,0,0");
    seek(TEMPLATE,0,0);
  }
  close(TEMPLATE);
  # Creating the trailer
  &debug("createIndexHtml(): Permited variables in main-trailer.html: <\$time_[hour,min,sec,day,mon,year]\$>");
  open(TEMPLATE, "$template/main-trailer.html") || die ("Fatal: Could not open template file $template/main-data.html ($!)\n");
  while(<TEMPLATE>) {
     $_ =~ s/<\$time_hour\$>/$hour/g;
     $_ =~ s/<\$time_min\$>/$min/g;
     $_ =~ s/<\$time_sec\$>/$sec/g;
     $_ =~ s/<\$time_day\$>/$day/g;
     $_ =~ s/<\$time_mon\$>/$mon/g;
     $_ =~ s/<\$time_year\$>/$year/g;
     print(INDEX "$_");
  }
  close(TEMPLATE);
  # ending procedure
  close(INDEX);
  &debug("createIndexHtml(): moving $graphdir/index-$randomic.temp to $graphdir/index.html");
  system("mv $graphdir/index-$randomic.temp $graphdir/index.html");
}

sub createIRCsHtml {
 # Now we create a file for each irc server
 my($sec,$min,$hour,$day,$mon,$year)=&horalocal();
 open(TEMPLATE, "$template/irc-data.html") || die ("Fatal: Could not open template file $template/irc-data.html ($!)\n");
 &debug("createIRCsHtml(): Permited variables in irc-data.html: <\$time_[hour,min,sec,day,mon,year]\$>,<\$connectto\$>,<\$ircport\$>,<\$ircname\$>");
 for (my($i)=0; $i <= $#servers; $i++) { # For each server, print an HTML file
  	(open(IRCHTML,">$graphdir/$servers[$i][0]-$randomic.temp") && &debug("createIRCsHtml(): Opening $servers[$i][0]-$randomic.temp file\n")) || die("Fatal: Could not create $graphdir/$servers[$i][0]-$randomic.temp ($!)\n");
  	while (<TEMPLATE>) {
	     $_ =~ s/<\$time_hour\$>/$hour/g;
	     $_ =~ s/<\$time_min\$>/$min/g;
	     $_ =~ s/<\$time_sec\$>/$sec/g;
	     $_ =~ s/<\$time_day\$>/$day/g;
	     $_ =~ s/<\$time_mon\$>/$mon/g;
	     $_	=~ s/<\$time_year\$>/$year/g;
	     $_ =~ s/<\$ircname\$>/$servers[$i][0]/g;
	     $_ =~ s/<\$connecto\$>/$connectto/g;
	     $_ =~ s/<\$ircport\$>/$ircport/g;
       	     print(IRCHTML "$_");
       }
       seek(TEMPLATE,0,0);
       close(IRCHTML);
       &debug("createIRCsHtml(): moving $graphdir/$servers[$i][0]-$randomic.temp to $graphdir/$servers[$i][0].html");
       system("mv $graphdir/$servers[$i][0]-$randomic.temp $graphdir/$servers[$i][0].html");
 }
 close(TEMPLATE);
}


sub createNetworkHtml {
 my($sec,$min,$hour,$day,$mon,$year)=&horalocal();
 open(TEMPLATE, "$template/net-data.html") || die ("Fatal: Could not open template file $template/net-data.html ($!)\n");
 &debug("createNetworkHtml(): Permited variables in net-data.html: <\$time_[hour,min,sec,day,mon,year]\$>,<\$connectto\$>,<\$ircport\$>");
 (open(NETHTML,">$graphdir/network-$randomic.temp") && &debug("createNetworkHtml(): Opening network-$randomic.temp file\n")) || die("Fatal: Could not create $graphdir/network-$randomic.temp\n");
	while(<TEMPLATE>) {
	     $_ =~ s/<\$time_hour\$>/$hour/g;
	     $_ =~ s/<\$time_min\$>/$min/g;
	     $_ =~ s/<\$time_sec\$>/$sec/g;
	     $_ =~ s/<\$time_day\$>/$day/g;
	     $_ =~ s/<\$time_mon\$>/$mon/g;
	     $_	=~ s/<\$time_year\$>/$year/g;
	     $_ =~ s/<\$connecto\$>/$connectto/g;
	     $_ =~ s/<\$ircport\$>/$ircport/g;
       	     print(NETHTML "$_");
	}
 close(TEMPLATE);
 close(NETHTML);
 &debug("createNetworkHtml(): moving $graphdir/network-$randomic.temp to $graphdir/network.html");
 system("mv $graphdir/network-$randomic.temp $graphdir/network.html");
}

sub createServersHtml {
 my($sec,$min,$hour,$day,$mon,$year)=&horalocal();
 open(TEMPLATE, "$template/servers-data.html") || die("Fatal: Could not open template file $template/servers-data.html ($!)\n");
 &debug("createServersHtml(): Permited variables in net-data.html: <\$time_[hour,min,sec,day,mon,year]\$>,<\$connectto\$>,<\$ircport\$>");
 (open(SERVERSHTML,">$graphdir/servers-$randomic.temp") && &debug("createServersHtml(): Opening servers-$randomic.temp file\n")) || die("Fatal: Could not create $graphdir/servers-$randomic.temp\n");
	while(<TEMPLATE>) {
	     $_ =~ s/<\$time_hour\$>/$hour/g;
	     $_ =~ s/<\$time_min\$>/$min/g;
	     $_ =~ s/<\$time_sec\$>/$sec/g;
	     $_ =~ s/<\$time_day\$>/$day/g;
	     $_ =~ s/<\$time_mon\$>/$mon/g;
	     $_	=~ s/<\$time_year\$>/$year/g;
	     $_ =~ s/<\$connectto\$>/$connectto/g;
	     $_ =~ s/<\$ircport\$>/$ircport/g;
       	     print(SERVERSHTML "$_");
	}
 close(TEMPLATE);
 close(SERVERSHTML);
 &debug("createServersHtml(): moving $graphdir/servers-$randomic.temp to $graphdir/servers.html");
 system("mv $graphdir/servers-$randomic.temp $graphdir/servers.html");
}


&createGraphs(1);
&createGraphs(2);
&createGraphs(3);

sub createGraphs {
 my($tipo)=@_;
 my($timepast)="";
 my($string_color)="-c BACK#$colors->[0] -c CANVAS#$colors->[1] -c SHADEA#$colors->[2] -c SHADEB#$colors->[3] -c GRID#$colors->[4] -c MGRID#$colors->[5] -c FONT#$colors->[6] -c FRAME#$colors->[7] -c ARROW#$colors->[8]";
 &debug("createGraphs(): Color string: $string_color");
 if ($tipo == 1) { # ircops and servers connected
	my($string_perc)="GPRINT:percircops:LAST:'Ircops\\: %.2lf%% of total users\\l'";
	my($string_legend)="";
        &debug("createGraphs(): ircops\/servers on line\n");
	# This 1st graph can't enter the for loop cos it has some extra info
	&debug("createGraphs(): ircops: #$colors->[12] servers: #$colors->[14]");
	if ($options->[0]==1) { $string_perc=""; }
	if ($options->[1]==1) { $string_legend="--no-legend"; }
 	system("$rrdtool graph $graphdir/servers-day.png $string_legend $string_color -a PNG -s -1day -v \"servers/ircops\" -t \"Servers and ircops on line (1 day)\" DEF:totalservers=$rrddir/$servers[0][0].rrd:totalservers:AVERAGE DEF:maxservers=$rrddir/$servers[0][0].rrd:totalservers:MAX DEF:totalircops=$rrddir/$servers[0][0].rrd:ircops:AVERAGE DEF:maxircops=$rrddir/$servers[0][0].rrd:ircops:MAX DEF:usuariosglobais=$rrddir/$servers[0][0].rrd:usuariosglobais:AVERAGE \"CDEF:copsperserver=totalircops,totalservers,\/\" \"CDEF:percircops=totalircops,100,*,usuariosglobais,\/\" AREA:totalservers#$colors->[14]:\"Servers on line\" LINE2:totalircops#$colors->[12]:\"Ircops on line\\l\" GPRINT:totalservers:AVERAGE:\'Servers -> Average\\: %.lf\' GPRINT:maxservers:MAX:\'Max\\: %.lf\' GPRINT:totalservers:LAST:\'Current\\: %.lf\\l\' GPRINT:totalircops:AVERAGE:\'Ircops -> Average\\: %.lf\' GPRINT:maxircops:MAX:\'Max\\: %.lf\' GPRINT:totalircops:LAST:\'Current\\: %.lf\\l' GPRINT:copsperserver:LAST:'Ircops per Server\\: %.2lf\\l' $string_perc")==0 || die("Fatal: Could no create servers-day.png ($!)\n");
	for $timepast ("week","month","year") {
		system("$rrdtool graph $graphdir/servers-$timepast.png $string_legend $string_color -a PNG -s -1$timepast -v \"servers/ircops\" -t \"Servers and ircops on line (1 $timepast)\" DEF:totalservers=$rrddir/$servers[0][0].rrd:totalservers:AVERAGE DEF:maxservers=$rrddir/$servers[0][0].rrd:totalservers:MAX DEF:totalircops=$rrddir/$servers[0][0].rrd:ircops:AVERAGE DEF:maxircops=$rrddir/$servers[0][0].rrd:ircops:MAX DEF:usuariosglobais=$rrddir/$servers[0][0].rrd:usuariosglobais:AVERAGE AREA:totalservers#$colors->[14]:\"Servers on line\" LINE2:totalircops#$colors->[12]:\"Ircops on line\\l\" GPRINT:totalservers:AVERAGE:\'Servers -> Average\\: %.lf\' GPRINT:maxservers:MAX:\'Max\\: %.lf\' GPRINT:totalservers:LAST:\'Current\\: %.lf\\l\' GPRINT:totalircops:AVERAGE:\'Ircops -> Average\\: %.lf\' GPRINT:maxircops:MAX:\'Max\\: %.lf\' GPRINT:totalircops:LAST:\'Current\\: %.lf\\l'")==0 || die("Fatal: Could not create servers-$timepast.png ($!)\n");
	}
  } elsif ($tipo == 2) {   # channels and users in the network
	my($string_perc)="GPRINT:percinvisible:LAST:'Invisible (+i)\\: %.2lf%% of total users\\l' GPRINT:percnormais:LAST:'Visible (-i)\\: %.2lf%% of total users\\l'";
	my($string_legend)="";
	if ($options->[0]==1) { $string_perc=""; }
	if ($options->[1]==1) { $string_legend="--no-legend"; }
	# Again, this first one is not on the for loop
	&debug("createGraphs(): users\/channels in the network\n");
	&debug("createGraphs(): users: #$colors->[9] invusers: #$colors->[10] noninvusers: #$colors->[11] channels: #$colors->[13]");
	system("$rrdtool graph $graphdir/network-day.png $string_legend $string_color -a PNG -h 200 -s -1day -v \"users/channels\" -t \"Users and channels in the network (1 day)\" DEF:usuariosglobais=$rrddir/$servers[0][0].rrd:usuariosglobais:AVERAGE DEF:canais=$rrddir/$servers[0][0].rrd:canais:AVERAGE \"CDEF:usersperchannel=usuariosglobais,canais,\/\"  DEF:invisiveis=$rrddir/$servers[0][0].rrd:invisiveis:AVERAGE DEF:normais=$rrddir/$servers[0][0].rrd:normais:AVERAGE \"CDEF:percinvisible=invisiveis,100,*,usuariosglobais,\/\" \"CDEF:percnormais=normais,100,*,usuariosglobais,\/\" AREA:usuariosglobais#$colors->[9]:\"Users connected\" LINE2:canais#$colors->[13]:\"Channels created\" LINE2:invisiveis#$colors->[10]:\"Users +i\" LINE2:normais#$colors->[11]:\"Users -i\" DEF:maxusers=$rrddir/$servers[0][0].rrd:usuariosglobais:MAX DEF:maxcanais=$rrddir/$servers[0][0].rrd:canais:MAX GPRINT:maxusers:MAX:'Users -> Max\\: %.lf' GPRINT:usuariosglobais:AVERAGE:'Average\\: %.lf' GPRINT:usuariosglobais:LAST:'Current\\: %.lf\\l' GPRINT:maxcanais:MAX:'Channels -> Max\\: %.lf' GPRINT:canais:AVERAGE:'Average\\: %.lf' GPRINT:canais:LAST:'Current\\: %.lf\\l' GPRINT:usersperchannel:LAST:'Users per channel\\: %.2lf\\l' $string_perc")==0 || die("Fatal: Could not create network-day.png ($!)\n");
	for $timepast ("week","month","year") {
	system("$rrdtool graph $graphdir/network-$timepast.png $string_legend $string_color -a PNG -h 200 -s -1$timepast -v \"users/channels\" -t \"Users and channels in the network (1 $timepast)\" DEF:usuariosglobais=$rrddir/$servers[0][0].rrd:usuariosglobais:AVERAGE DEF:canais=$rrddir/$servers[0][0].rrd:canais:AVERAGE DEF:invisiveis=$rrddir/$servers[0][0].rrd:invisiveis:AVERAGE DEF:normais=$rrddir/$servers[0][0].rrd:normais:AVERAGE AREA:usuariosglobais#$colors->[9]:\"Users connected\" LINE2:canais#$colors->[13]:\"Channels created\" LINE2:invisiveis#$colors->[10]:\"Users +i\" LINE2:normais#$colors->[11]:\"Users -i\" DEF:maxusers=$rrddir/$servers[0][0].rrd:usuariosglobais:MAX DEF:maxcanais=$rrddir/$servers[0][0].rrd:canais:MAX GPRINT:maxusers:MAX:'Users -> Max\\: %.lf' GPRINT:usuariosglobais:AVERAGE:'Average\\: %.lf' GPRINT:usuariosglobais:LAST:'Current\\: %.lf\\l' GPRINT:maxcanais:MAX:'Channels -> Max\\: %.lf' GPRINT:canais:AVERAGE:'Average\\: %.lf' GPRINT:canais:LAST:'Current\\: %.lf\\l'")==0 || die("Fatal: Could not create network-$timepast.png ($!)\n");
	}
 } elsif ($tipo == 3) {	   # local users and servers
  for (my($i)=0; $i <= $#servers; $i++) {
        my($string_perc)="GPRINT:perclocais:LAST:'Percentage\\: $servers[$i][0] has %.2lf%% of global users\\l'";
	my($string_legend)="";
	if ($options->[0]==1) { $string_perc=""; }
	if ($options->[1]==1) { $string_legend="--no-legend"; }
	&debug("createGraphs(): local users from: $servers[$i][0]\n");
	# The same old story
 	system("$rrdtool graph $graphdir/$servers[$i][0]-day.png $string_legend $string_color -a PNG -v \"local users\" -t \"Users connected to $servers[$i][0] (1 day)\" DEF:lastglobais=$rrddir/$servers[$i][0].rrd:usuariosglobais:AVERAGE DEF:usuarioslocais=$rrddir/$servers[$i][0].rrd:usuarioslocais:AVERAGE \"CDEF:perclocais=usuarioslocais,100,*,lastglobais,\/\" AREA:usuarioslocais#$colors->[9]:\"Users connected to $servers[$i][0]\\l\" DEF:maxlocais=$rrddir/$servers[$i][0].rrd:usuarioslocais:MAX GPRINT:maxlocais:MAX:'Users -> Max\\: %.lf' GPRINT:usuarioslocais:AVERAGE:'Average\\: %.lf' GPRINT:usuarioslocais:LAST:'Current\\: %.lf\\l' $string_perc")==0 || die("Fatal: Could not create irc-day.png ($!)\n");
	for $timepast ("week","month","year") {
	 	system("$rrdtool graph $graphdir/$servers[$i][0]-$timepast.png $string_legend $string_color -a PNG -s -1$timepast -v \"local users\" -t \"Users connected to $servers[$i][0] (1 $timepast)\" DEF:usuarioslocais=$rrddir/$servers[$i][0].rrd:usuarioslocais:AVERAGE AREA:usuarioslocais#$colors->[9]:\"Users connected to $servers[$i][0]\\l\" DEF:maxlocais=$rrddir/$servers[$i][0].rrd:usuarioslocais:MAX GPRINT:maxlocais:MAX:'Users -> Max\\: %.lf' GPRINT:usuarioslocais:AVERAGE:'Average\\: %.lf' GPRINT:usuarioslocais:LAST:'Current\\: %.lf users\\l'")==0 || die("Fatal: Could not create irc-$timepast.png ($!)\n");
	}
  } 
 }
 return(1);
}


sub readconf {
 my($config)=@_;
 my(@dados)=("","","","","","","","","","");
 open(CONFIG,"$config") || die("Fatal: could not read $config ($!)\n"); 
 while (<CONFIG>) {
  if (($_ !~ /^#.*$/) && ($_ !~ /^ *$/)) { # if there'snt # in the beginning and is not empty, go on
   chomp($_);	# damned /n ;)
   my(@splited)=split(" *= *",$_);
    if ($splited[0] =~ /( *connectto *| *ircport *| *rrdtool *| *rrddir *| *ircservers *| *htmldir *| *template *| *colors *| *options *)/) {
     if (!$splited[1]) {
      die("Fatal: Invalid entry - line $. :\"$_\"\n");
     } else {
      if ($splited[0] =~ / *rrdtool */i) { $dados[1]=$splited[1]; }
      elsif ($splited[0] =~ / *connectto */i) { $dados[2]=$splited[1]; }
      elsif ($splited[0] =~ / *ircport */i) { $dados[3]=$splited[1]; }
      elsif ($splited[0] =~ / *ircservers */i) { $dados[4]=$splited[1]; }
      elsif ($splited[0] =~ / *htmldir */i) { $dados[5]=$splited[1]; }
      elsif ($splited[0] =~ / *rrddir */i) { $dados[7]=$splited[1]; }
      elsif ($splited[0] =~ / *template */i) { $dados[8]=$splited[1]; }
      elsif ($splited[0] =~ / *colors */i) { $dados[9]=$splited[1]; }
      elsif ($splited[0] =~ / *options */i) { $dados[10]=$splited[1]; }
     }
    }
   }
  }
 return(@dados);
}

sub horalocal {
 (my(@hora)=(localtime(time()))[0,1,2,3,4,5]);
 my($var);
 for ($var=0; $var<5; $var++) {
  if (length($hora[$var]) <= 1) {
   $hora[$var] = "0".$hora[$var];
  }
 }
 $hora[4]=$hora[4]+1;
 $hora[5]=$hora[5]+1900;
 return(@hora);
}

sub debug {
 if ($opt_d) {
  my($parm1) = @_;
  chomp($parm1);
  print($parm1,"\n");
 }
 return(1);
}

sub parseOptions {
  my(@opcoes)=(-1,-1);
  my($totaloptions)=@_;
  if ($totaloptions) { 
	  my(@splited)=split(",",$totaloptions);
	  for (my($i)=0; $i < scalar(@splited); $i++) {
	    if ($splited[$i] =~ / *noperc */i) { $opcoes[0]=1; }
	    elsif ($splited[$i] =~ / *nolegend */i) { $opcoes[1]=1; }
	    #elsif ($splited[$i] =~ / *bytes */) { $opcoes[4]=1; }
	  }
  }
  return(\@opcoes);
}


sub parseColors {
	my($colors)=@_;
	$colors=~s/ *//g;
	&debug("parseColors(): Entering parseColors ($colors)");
	my(@cores)=("FFFFFF","F3F3F3","C8C8C8","969696","8C8C8C","821E1E","000000","000000","FF0000","FF0000","00FF00","000000","000000","0000FF","FF0000");
	if ($colors) {
		&debug("parseColors(): yes, \$colors is defined");
		my(@splited)=split(",",$colors);
		for (my($i)=0; $i < scalar(@splited); $i++) {
	          my(@split)=split("#",$splited[$i]);
		  if ($split[1] =~ /[0-9,A-F]{6}/i) {
			$splited[0]=lc($splited[0]); 
			#$splited[0]=~s/ +//g; $splited[1]=~s/ +//g;
			&debug("parseColors(): Parsing color: ($split[0]) ($split[1])");
    			if ($split[0] eq "back") { $cores[0]=$split[1]; &debug("parseColors: back: $split[1]"); }
			if ($split[0] eq "canvas") { $cores[1]=$split[1]; &debug("parseColors: canvas: $split[1]"); }
			if ($split[0] eq "shadea") { $cores[2]=$split[1]; &debug("parseColors: shadea: $split[1]");}
			if ($split[0] eq "shadeb") { $cores[3]=$split[1]; &debug("parseColors: shadeb: $split[1]");}
			if ($split[0] eq "grid") { $cores[4]=$split[1]; &debug("parseColors: grid: $split[1]");}
			if ($split[0] eq "mgrid") { $cores[5]=$split[1]; &debug("parseColors: mgrid: $split[1]");}
			if ($split[0] eq "font") { $cores[6]=$split[1]; &debug("parseColors: font: $split[1]");}
			if ($split[0] eq "frame") { $cores[7]=$split[1]; &debug("parseColors: frame: $split[1]");}
			if ($split[0] eq "arrow") { $cores[8]=$split[1]; &debug("parseColors: arrow: $split[1]");}
			if ($split[0] eq "users") { $cores[9]=$split[1]; &debug("parseColors: users: $split[1]");}
			if ($split[0] eq "iusers") { $cores[10]=$split[1]; &debug("parseColors: iusers: $split[1]");}
			if ($split[0] eq "niusers") { $cores[11]=$split[1]; &debug("parseColors: niusers: $split[1]");}
			if ($split[0] eq "ircops") { $cores[12]=$split[1]; &debug("parseColors: ircops: $split[1]");}
			if ($split[0] eq "channels") { $cores[13]=$split[1]; &debug("parseColors: channels: $split[1]");}
			if ($split[0] eq "servers") { $cores[14]=$split[1]; &debug("parseColors: servers: $split[1]");}
		  } else {	
			&debug("parseColors(): $split[1] does not matches XXXXXX format color");
		}
	}	
	} else {
		&debug("parseColors(): no color option defined");
	}
	&debug("parseColors(): back#$cores[0] canvas#$cores[1] shadea#$cores[2] shadeb#$cores[3] grid#$cores[4] mgrid#$cores[5] font#$cores[6] frame#$cores[7] arrow#$cores[8] users#$cores[9] iusers#$cores[10] niusers#$cores[11] ircops#$cores[12] channels#$cores[13] servers#$cores[14]");
	return(\@cores);
}
